@@ -455,7 +455,8 @@ class Defaults:
             'crypto',
             'cryptodisk',
             'test',
-            'true'
+            'true',
+            'loadenv'
         ]
         if multiboot:
             modules.append('multiboot')
@@ -1274,7 +1275,7 @@ class Defaults:
 
         :rtype: list
         """
-        return ['oem', 'vmx']
+        return ['oem']
 
     @staticmethod
     def get_live_image_types():
