@@ -21,6 +21,7 @@ import logging
 from kiwi.package_manager.zypper import PackageManagerZypper
 from kiwi.package_manager.apt import PackageManagerApt
 from kiwi.package_manager.dnf import PackageManagerDnf
+from kiwi.package_manager.pacman import PackageManagerPacman
 
 from kiwi.exceptions import (
     KiwiPackageManagerSetupError
@@ -50,6 +51,8 @@ class PackageManager:
             manager = PackageManagerDnf(repository, custom_args)
         elif package_manager == 'apt-get':
             manager = PackageManagerApt(repository, custom_args)
+        elif package_manager == 'pacman':
+            manager = PackageManagerPacman(repository, custom_args)
         else:
             raise KiwiPackageManagerSetupError(
                 'Support for package manager %s not implemented' %
