@@ -41,7 +41,7 @@ class DiskSetup:
         self.root_filesystem_is_overlay = xml_state.build_type.get_overlayroot()
         self.swap_mbytes = xml_state.get_oemconfig_swap_mbytes()
         self.configured_size = xml_state.get_build_type_size()
-        self.build_type_name = xml_state.get_build_type_name()
+        self.disk_resize_requested = xml_state.get_oemconfig_oem_resize()
         self.filesystem = xml_state.build_type.get_filesystem()
         self.bootpart_requested = xml_state.build_type.get_bootpartition()
         self.bootpart_mbytes = xml_state.build_type.get_bootpartsize()
@@ -278,10 +278,10 @@ class DiskSetup:
         data_volume_mbytes = self._calculate_volume_mbytes()
         root_volume = self._get_root_volume_configuration()
 
-        # For oem types we only add the default min volume size
-        # because their target size request is handled on first boot
-        # of the disk image in oemboot/repart
-        if self.build_type_name == 'oem':
+        # If disk resize is requested we only add the default min
+        # volume size because their target size request is handled
+        # on first boot of the disk image in oemboot/repart
+        if self.disk_resize_requested:
             for volume in self.volumes:
                 disk_volume_mbytes += Defaults.get_min_volume_mbytes()
             return disk_volume_mbytes
