@@ -53,6 +53,17 @@ class Profile:
         self._drivers_to_profile()
         self._root_partition_uuid_to_profile()
 
+    def get_settings(self):
+        """
+        Return all profile elements that has a value
+        """
+        profile = {}
+        for key, value in list(self.dot_profile.items()):
+            profile[key] = Shell.format_to_variable_value(value)
+        return collections.OrderedDict(
+            sorted(profile.items())
+        )
+
     def add(self, key, value):
         """
         Add key/value pair to profile dictionary
@@ -72,16 +83,13 @@ class Profile:
 
         :param str filename: file path name
         """
-        sorted_profile = collections.OrderedDict(
-            sorted(self.dot_profile.items())
-        )
+        sorted_profile = self.get_settings()
         temp_profile = NamedTemporaryFile()
         with open(temp_profile.name, 'w') as profile:
             for key, value in list(sorted_profile.items()):
-                if value:
-                    profile.write(
-                        format(key) + '=' + self._format(value) + '\n'
-                    )
+                profile.write(
+                    '{0}={1}{2}'.format(key, value, os.linesep)
+                )
         profile_environment = Shell.quote_key_value_file(temp_profile.name)
         with open(filename, 'w') as profile:
             for line in profile_environment:
@@ -382,13 +390,3 @@ class Profile:
                 return 'true'
             else:
                 return content
-
-    def _format(self, value):
-        """
-        Helper method to format bool profile values in the way
-        the boot code expects them
-        """
-        if value is True:
-            return 'true'
-        else:
-            return format(value)
