@@ -140,9 +140,12 @@ class XMLState:
         if self.get_build_type_name() in ['vmx', 'iso', 'kis']:
             # vmx, iso and kis image types always use dracut as initrd system
             initrd_system = 'dracut'
-        elif self.get_build_type_name() in ['oem', 'pxe']:
-            # pxe and oem image types default to kiwi if unset
+        elif self.get_build_type_name() == 'pxe':
+            # pxe image type defaults to kiwi if unset
             initrd_system = self.build_type.get_initrd_system() or 'kiwi'
+        elif self.get_build_type_name() == 'oem':
+            # oem image type defaults to dracut if unset
+            initrd_system = self.build_type.get_initrd_system() or 'dracut'
         else:
             initrd_system = self.build_type.get_initrd_system()
         return initrd_system
@@ -395,7 +398,7 @@ class XMLState:
         )
         if package_list:
             for package in package_list:
-                result.append(package.package_section.get_name())
+                result.append(package.package_section.get_name().strip())
             if self.get_system_packages():
                 result.append(self.get_package_manager())
         if plus_packages:
@@ -420,7 +423,7 @@ class XMLState:
         )
         if package_list:
             for package in package_list:
-                result.append(package.package_section.get_name())
+                result.append(package.package_section.get_name().strip())
         return sorted(list(set(result)))
 
     def get_bootstrap_archives(self):
@@ -438,7 +441,7 @@ class XMLState:
                 archive_list = bootstrap_packages_section.get_archive()
                 if archive_list:
                     for archive in archive_list:
-                        result.append(archive.get_name())
+                        result.append(archive.get_name().strip())
         return sorted(result)
 
     def get_system_archives(self):
@@ -456,7 +459,7 @@ class XMLState:
         )
         for packages in image_packages_sections:
             for archive in packages.get_archive():
-                result.append(archive.get_name())
+                result.append(archive.get_name().strip())
         return sorted(result)
 
     def get_system_ignore_packages(self):
@@ -475,7 +478,7 @@ class XMLState:
         for packages in image_packages_sections:
             for package in packages.get_ignore():
                 if self.package_matches_host_architecture(package):
-                    result.append(package.get_name())
+                    result.append(package.get_name().strip())
         return sorted(result)
 
     def get_collection_type(self, section_type='image'):
@@ -858,6 +861,21 @@ class XMLState:
         if oemconfig_sections:
             return oemconfig_sections[0]
 
+    def get_oemconfig_oem_resize(self):
+        """
+        State value to activate/deactivate disk resize. Returns a
+        boolean value if specified or True to set resize on by default
+
+        :return: Content of <oem-resize> section value
+
+        :rtype: bool
+        """
+        oemconfig = self.get_build_type_oemconfig_section()
+        if oemconfig and oemconfig.get_oem_resize():
+            return oemconfig.get_oem_resize()[0]
+        else:
+            return True
+
     def get_oemconfig_oem_multipath_scan(self):
         """
         State value to activate multipath maps. Returns a boolean
