@@ -56,13 +56,13 @@ class TestXMLState:
         assert description.author == 'Marcus'
         assert description.contact == 'ms@suse.com'
         assert description.specification == \
-            'openSUSE 13.2 JeOS, is a small text based image'
+            'Testing various configuration states'
 
     def test_build_type_primary_selected(self):
         assert self.state.get_build_type_name() == 'oem'
 
     def test_build_type_first_selected(self):
-        self.state.xml_data.get_preferences()[1].get_type()[0].set_primary(
+        self.state.xml_data.get_preferences()[2].get_type()[0].set_primary(
             False
         )
         assert self.state.get_build_type_name() == 'oem'
@@ -266,8 +266,8 @@ class TestXMLState:
 
     def test_build_type_explicitly_selected(self):
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['vmxFlavour'], 'vmx')
-        assert state.get_build_type_name() == 'vmx'
+        state = XMLState(xml_data, ['vmxFlavour'], 'oem')
+        assert state.get_build_type_name() == 'oem'
 
     def test_build_type_not_found(self):
         xml_data = self.description.load()
@@ -289,7 +289,7 @@ class TestXMLState:
         xml_data = self.description.load()
         xml_state = XMLState(xml_data, ['composedProfile'])
         assert xml_state.profiles == [
-            'composedProfile', 'vmxFlavour', 'xenFlavour'
+            'composedProfile', 'vmxSimpleFlavour', 'xenDomUFlavour'
         ]
 
     def test_get_volumes(self):
@@ -431,7 +431,7 @@ class TestXMLState:
 
     def test_get_build_type_machine_section(self):
         xml_data = self.description.load()
-        state = XMLState(xml_data, None, 'vmx')
+        state = XMLState(xml_data, ['vmxSimpleFlavour'], 'oem')
         assert state.get_build_type_machine_section().get_guestOS() == 'suse'
 
     def test_get_drivers_list(self):
@@ -444,9 +444,20 @@ class TestXMLState:
         assert state.get_build_type_oemconfig_section().get_oem_swap()[0] is \
             True
 
+    def test_get_oemconfig_oem_resize(self):
+        xml_data = self.description.load()
+        state = XMLState(xml_data, ['vmxFlavour'], 'oem')
+        assert state.get_oemconfig_oem_resize() is True
+        description = XMLDescription(
+            '../data/example_multiple_users_config.xml'
+        )
+        xml_data = description.load()
+        state = XMLState(xml_data)
+        assert state.get_oemconfig_oem_resize() is False
+
     def test_get_oemconfig_swap_mbytes(self):
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['xenFlavour'], 'docker')
+        state = XMLState(xml_data, ['containerFlavour'], 'docker')
         assert state.get_oemconfig_swap_mbytes() is None
         state = XMLState(xml_data, ['vmxFlavour'], 'oem')
         assert state.get_oemconfig_swap_mbytes() == 42
@@ -591,7 +602,7 @@ class TestXMLState:
         assert result.additive
 
     def test_build_type_size_with_unpartitioned(self):
-        state = XMLState(self.description.load(), ['vmxFlavour'], 'vmx')
+        state = XMLState(self.description.load(), ['vmxSimpleFlavour'], 'oem')
         result = state.get_build_type_size()
         assert result.mbytes == 3072
         assert not result.additive
@@ -601,11 +612,11 @@ class TestXMLState:
 
     def test_get_build_type_unpartitioned_bytes(self):
         assert self.state.get_build_type_unpartitioned_bytes() == 0
-        state = XMLState(self.description.load(), ['vmxFlavour'], 'vmx')
+        state = XMLState(self.description.load(), ['vmxSimpleFlavour'], 'oem')
         assert state.get_build_type_unpartitioned_bytes() == 1073741824
         state = XMLState(self.description.load(), ['vmxFlavour'], 'oem')
         assert state.get_build_type_unpartitioned_bytes() == 0
-        state = XMLState(self.description.load(), ['ec2Flavour'], 'vmx')
+        state = XMLState(self.description.load(), ['ec2Flavour'], 'oem')
         assert state.get_build_type_unpartitioned_bytes() == 0
 
     def test_get_volume_group_name(self):
@@ -649,9 +660,9 @@ class TestXMLState:
     def test_get_build_type_vmconfig_entries(self):
         assert self.state.get_build_type_vmconfig_entries() == []
 
-    def test_get_build_type_vmconfig_entries_for_vmx_type(self):
+    def test_get_build_type_vmconfig_entries_for_simple_disk(self):
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['vmxFlavour'], 'vmx')
+        state = XMLState(xml_data, ['vmxSimpleFlavour'], 'oem')
         assert state.get_build_type_vmconfig_entries() == [
             'numvcpus = "4"', 'cpuid.coresPerSocket = "2"'
         ]
@@ -664,7 +675,7 @@ class TestXMLState:
 
     def test_get_build_type_docker_containerconfig_section(self):
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['vmxFlavour'], 'docker')
+        state = XMLState(xml_data, ['containerFlavour'], 'docker')
         containerconfig = state.get_build_type_containerconfig_section()
         assert containerconfig.get_name() == \
             'container_name'
@@ -675,14 +686,14 @@ class TestXMLState:
 
     def test_set_container_tag(self):
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['vmxFlavour'], 'docker')
+        state = XMLState(xml_data, ['containerFlavour'], 'docker')
         state.set_container_config_tag('new_tag')
         config = state.get_container_config()
         assert config['container_tag'] == 'new_tag'
 
     def test_add_container_label(self):
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['vmxFlavour'], 'docker')
+        state = XMLState(xml_data, ['containerFlavour'], 'docker')
         state.add_container_config_label('somelabel', 'overwrittenvalue')
         state.add_container_config_label('new_label', 'new value')
         config = state.get_container_config()
@@ -694,7 +705,7 @@ class TestXMLState:
 
     def test_add_container_label_without_contianerconfig(self):
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['xenFlavour'], 'docker')
+        state = XMLState(xml_data, ['xenDom0Flavour'], 'docker')
         state.add_container_config_label('somelabel', 'newlabelvalue')
         config = state.get_container_config()
         assert config['labels'] == {
@@ -703,7 +714,7 @@ class TestXMLState:
 
     def test_add_container_label_no_container_image_type(self):
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['vmxFlavour'], 'vmx')
+        state = XMLState(xml_data, ['vmxFlavour'], 'oem')
         state.add_container_config_label('somelabel', 'newlabelvalue')
         with self._caplog.at_level(logging.WARNING):
             config = state.get_container_config()
@@ -743,7 +754,7 @@ class TestXMLState:
             }
         }
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['vmxFlavour'], 'docker')
+        state = XMLState(xml_data, ['containerFlavour'], 'docker')
         assert state.get_container_config() == expected_config
 
     def test_get_container_config_clear_commands(self):
@@ -801,26 +812,26 @@ class TestXMLState:
     def test_is_xen_guest_by_firmware_setup(self, mock_platform_machine):
         mock_platform_machine.return_value = 'x86_64'
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['ec2Flavour'], 'vmx')
+        state = XMLState(xml_data, ['ec2Flavour'], 'oem')
         assert state.is_xen_guest() is True
 
     @patch('platform.machine')
     def test_is_xen_guest_by_architecture(self, mock_platform_machine):
         mock_platform_machine.return_value = 'unsupported'
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['ec2Flavour'], 'vmx')
+        state = XMLState(xml_data, ['ec2Flavour'], 'oem')
         assert state.is_xen_guest() is False
 
     def test_get_initrd_system(self):
         xml_data = self.description.load()
-        state = XMLState(xml_data, ['vmxFlavour'], 'vmx')
+        state = XMLState(xml_data, ['vmxFlavour'], 'oem')
         assert state.get_initrd_system() == 'dracut'
-        state = XMLState(xml_data, ['vmxFlavour'], 'iso')
+        state = XMLState(xml_data, ['vmxSimpleFlavour'], 'iso')
         assert state.get_initrd_system() == 'dracut'
-        state = XMLState(xml_data, ['vmxFlavour'], 'docker')
+        state = XMLState(xml_data, ['containerFlavour'], 'docker')
         assert state.get_initrd_system() is None
         state = XMLState(xml_data, [], 'oem')
-        assert state.get_initrd_system() == 'kiwi'
+        assert state.get_initrd_system() == 'dracut'
 
     def test_get_rpm_locale_filtering(self):
         assert self.state.get_rpm_locale_filtering() is True
